const Me = imports.misc.extensionUtils.getCurrentExtension();
const Log = Me.imports.modules.log;
const Resources = Me.imports.modules.resources;
const Gio = imports.gi.Gio;
var Profile = class Profile {
    constructor() {
        this.powerProfilesProxy = null;
        this.powerProfilesSignalProxy = null;
        this.connectedPPD = false;
        this.profiles = [];
        this.PROFILE_ICONS = {
            'performance': 'power-profile-performance-symbolic',
            'balanced': 'power-profile-balanced-symbolic',
            'power-saver': 'power-profile-power-saver-symbolic',
        };
    }
    getProfileNames() {
        if (this.isRunning()) {
            try {
                let _profiles = this.powerProfilesProxy.Profiles;
                if (_profiles.length > 0) {
                    for (const [_key, value] of Object.entries(_profiles)) {
                        this.profiles[parseInt(_key)] = {
                            'Profile': value.Profile.unpack(),
                            'Driver': value.Driver.unpack()
                        };
                    }
                }
            }
            catch (e) {
                Log.raw(`Power Profiles: failed to fetch profile names!`, e);
            }
        }
        return this.profiles;
    }
    setProfileFromSignal(name = '', variant, profile = []) {
        if (this.isRunning()) {
            try {
                if (profile.length > 0) {
                    for (const [_key, value] of Object.entries(profile)) {
                        if (typeof value == 'object') {
                            for (const [_keyInner, valueInner] of Object.entries(value)) {
                                if (_keyInner == 'ActiveProfile') {
                                    let currentProfile = valueInner.print(true);
                                    currentProfile = currentProfile.replaceAll("'", '');
                                    this.updateProfile(currentProfile);
                                    return true;
                                }
                            }
                        }
                    }
                }
            }
            catch (e) {
                Log.raw(`Power Profiles: failed to fetch profile names!`, e);
                return false;
            }
        }
    }
    updateProfile(curState = null) {
        ext.PowerProfileIndicatorInstance._indicator.icon_name = this.PROFILE_ICONS[curState];
        ext.PowerProfileIndicatorInstance._indicator.visible = true;
    }
    isRunning() {
        return this.connectedPPD;
    }
    async start() {
        try {
            let xmlProfiles = Resources.File.DBus('net.hadess.PowerProfiles-0.10.1');
            this.powerProfilesProxy = new Gio.DBusProxy.makeProxyWrapper(xmlProfiles)(Gio.DBus.system, 'net.hadess.PowerProfiles', '/net/hadess/PowerProfiles');
            let xmlSignals = Resources.File.DBus('net.hadess.PowerProfilesSignals-0.10.1');
            this.powerProfilesSignalProxy = new Gio.DBusProxy.makeProxyWrapper(xmlSignals)(Gio.DBus.system, 'org.freedesktop.DBus.Properties', '/net/hadess/PowerProfiles');
            this.connectedPPD = true;
            this.getProfileNames();
            this.updateProfile(await this.powerProfilesProxy.ActiveProfile);
            this.powerProfilesSignalProxy.connectSignal("PropertiesChanged", (name = '', variant, profile) => {
                this.setProfileFromSignal(name, variant, profile);
            });
        }
        catch (e) {
            Log.raw(`Power Profile DBus initialization failed!`, e);
        }
    }
    stop() {
        if (this.isRunning()) {
            this.connectedPPD = false;
            this.powerProfilesProxy = null;
            this.powerProfilesSignalProxy = null;
        }
    }
}
//# sourceMappingURL=profile_dbus.js.map